@@ -27,14 +27,16 @@ namespace Bastet{
 
   RandomBlockChooser::RandomBlockChooser(){}
   RandomBlockChooser::~RandomBlockChooser(){}
+  
   Queue RandomBlockChooser::GetStartingQueue(){
     Queue q;
-    q.push_back(BlockType(random()%7));
-    q.push_back(BlockType(random()%7));
+    q.push_back(BlockType(random()%nBlockTypes));
+    q.push_back(BlockType(random()%nBlockTypes));
     return q;
   }
+  
   BlockType RandomBlockChooser::GetNext(const Well *well, const Queue &q){
-    return BlockType(random()%7);
+    return BlockType(random()%nBlockTypes);
   }
   
 }
